pytomography.callbacks — PyTomography 0.8.0 documentation

Skip to main content
`Ctrl`+`K`

# `pytomography.callbacks`

Callbacks can be used to compute various metrics on a reconstructed object throughout each iteration in an iterative reconstruction algorithm. For example, you may want to look at the noise in the liver as a function of iteration number in OSEM. A callback is simply a class which can take in an object and perform an operation. Callbacks are optional input to reconstruction algorithms; the `run` method of a callback is called after each subiteration of an iterative reconstruction algorithm. All user-defined callbacks should inherit from the base class `CallBack`. A subclass of this class could be used to compute noise-bias curves provided the `__init__` method was redefined to take in some ground truth, and the run method was redefined to compare the obj to the ground truth.

## Submodules

- `pytomography.callbacks.callback`

## Package Contents

### Classes

`CallBack` | Abstract class used for callbacks. Subclasses must redefine the `__init__` and `run` methods. If a callback is used as an argument in an iterative reconstruction algorihtm, the `__run__` method is called after each subiteration.

class pytomography.callbacks.CallBack

  Abstract class used for callbacks. Subclasses must redefine the `__init__` and `run` methods. If a callback is used as an argument in an iterative reconstruction algorihtm, the `__run__` method is called after each subiteration.

  abstract run(obj, n_iter, n_subset)

    Abstract method for `run`.

    Parameters:

      - obj (torch.tensor[batch_size, Lx, Ly, Lz]) – An object which one can compute various statistics from.

      - n_iter (int) – The iteration number

      - n_subset (int) – The subiteration number